@@ -73,6 +73,8 @@ def _get_failed_checks(checks, col=None):
 
 parse_boolean = _parse_boolean
 """
+:sphinx-autoapi-skip:
+
 IMPORTANT!!! Keep it for compatibility with released 8.4.0 version of google provider.
 
 Unfortunately the provider used _get_failed_checks and parse_boolean as imports and we should
@@ -187,20 +189,22 @@ class BaseSQLOperator(BaseOperator):
 class SQLExecuteQueryOperator(BaseSQLOperator):
     """
     Executes SQL code in a specific database
-    :param sql: the SQL code or string pointing to a template file to be executed (templated).
-    File must have a '.sql' extensions.
 
     When implementing a specific Operator, you can also implement `_process_output` method in the
     hook to perform additional processing of values returned by the DB Hook of yours. For example, you
     can join description retrieved from the cursors of your statements with returned values, or save
     the output of your operator to a file.
 
+    :param sql: the SQL code or string pointing to a template file to be executed (templated).
+        File must have a '.sql' extension.
     :param autocommit: (optional) if True, each command is automatically committed (default: False).
     :param parameters: (optional) the parameters to render the SQL query with.
     :param handler: (optional) the function that will be applied to the cursor (default: fetch_all_handler).
     :param split_statements: (optional) if split single SQL string into statements. By default, defers
         to the default value in the ``run`` method of the configured hook.
     :param return_last: (optional) return the result of only last statement (default: True).
+    :param show_return_value_in_logs: (optional) if true operator output will be printed to the task log.
+        Use with caution. It's not recommended to dump large datasets to the log. (default: False).
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -221,6 +225,7 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         handler: Callable[[Any], Any] = fetch_all_handler,
         split_statements: bool | None = None,
         return_last: bool = True,
+        show_return_value_in_logs: bool = False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -230,6 +235,7 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         self.handler = handler
         self.split_statements = split_statements
         self.return_last = return_last
+        self.show_return_value_in_logs = show_return_value_in_logs
 
     def _process_output(self, results: list[Any], descriptions: list[Sequence[Sequence] | None]) -> list[Any]:
         """
@@ -248,8 +254,13 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         :param results: results in the form of list of rows.
         :param descriptions: list of descriptions returned by ``cur.description`` in the Python DBAPI
         """
+        if self.show_return_value_in_logs:
+            self.log.info("Operator output is: %s", results)
         return results
 
+    def _should_run_output_processing(self) -> bool:
+        return self.do_xcom_push
+
     def execute(self, context):
         self.log.info("Executing: %s", self.sql)
         hook = self.get_db_hook()
@@ -261,11 +272,11 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
             sql=self.sql,
             autocommit=self.autocommit,
             parameters=self.parameters,
-            handler=self.handler if self.do_xcom_push else None,
+            handler=self.handler if self._should_run_output_processing() else None,
             return_last=self.return_last,
             **extra_kwargs,
         )
-        if not self.do_xcom_push:
+        if not self._should_run_output_processing():
             return None
         if return_single_query_results(self.sql, self.return_last, self.split_statements):
             # For simplicity, we pass always list as input to _process_output, regardless if
@@ -286,40 +297,41 @@ class SQLColumnCheckOperator(BaseSQLOperator):
     Checks are performed on a per-column basis specified by the column_mapping.
 
     Each check can take one or more of the following options:
-    - equal_to: an exact value to equal, cannot be used with other comparison options
-    - greater_than: value that result should be strictly greater than
-    - less_than: value that results should be strictly less than
-    - geq_to: value that results should be greater than or equal to
-    - leq_to: value that results should be less than or equal to
-    - tolerance: the percentage that the result may be off from the expected value
-    - partition_clause: an extra clause passed into a WHERE statement to partition data
+
+    * ``equal_to``: an exact value to equal, cannot be used with other comparison options
+    * ``greater_than``: value that result should be strictly greater than
+    * ``less_than``: value that results should be strictly less than
+    * ``geq_to``: value that results should be greater than or equal to
+    * ``leq_to``: value that results should be less than or equal to
+    * ``tolerance``: the percentage that the result may be off from the expected value
+    * ``partition_clause``: an extra clause passed into a WHERE statement to partition data
 
     :param table: the table to run checks on
     :param column_mapping: the dictionary of columns and their associated checks, e.g.
 
-    .. code-block:: python
+        .. code-block:: python
 
-        {
-            "col_name": {
-                "null_check": {
-                    "equal_to": 0,
-                    "partition_clause": "foreign_key IS NOT NULL",
-                },
-                "min": {
-                    "greater_than": 5,
-                    "leq_to": 10,
-                    "tolerance": 0.2,
-                },
-                "max": {"less_than": 1000, "geq_to": 10, "tolerance": 0.01},
+            {
+                "col_name": {
+                    "null_check": {
+                        "equal_to": 0,
+                        "partition_clause": "foreign_key IS NOT NULL",
+                    },
+                    "min": {
+                        "greater_than": 5,
+                        "leq_to": 10,
+                        "tolerance": 0.2,
+                    },
+                    "max": {"less_than": 1000, "geq_to": 10, "tolerance": 0.01},
+                }
             }
-        }
 
     :param partition_clause: a partial SQL statement that is added to a WHERE clause in the query built by
         the operator that creates partition_clauses for the checks to run on, e.g.
 
-    .. code-block:: python
+        .. code-block:: python
 
-        "date = '1970-01-01'"
+            "date = '1970-01-01'"
 
     :param conn_id: the connection ID used to connect to the database
     :param database: name of database which overwrite the defined one in connection
@@ -534,21 +546,21 @@ class SQLTableCheckOperator(BaseSQLOperator):
     :param checks: the dictionary of checks, where check names are followed by a dictionary containing at
         least a check statement, and optionally a partition clause, e.g.:
 
-    .. code-block:: python
+        .. code-block:: python
 
-        {
-            "row_count_check": {"check_statement": "COUNT(*) = 1000"},
-            "column_sum_check": {"check_statement": "col_a + col_b < col_c"},
-            "third_check": {"check_statement": "MIN(col) = 1", "partition_clause": "col IS NOT NULL"},
-        }
+            {
+                "row_count_check": {"check_statement": "COUNT(*) = 1000"},
+                "column_sum_check": {"check_statement": "col_a + col_b < col_c"},
+                "third_check": {"check_statement": "MIN(col) = 1", "partition_clause": "col IS NOT NULL"},
+            }
 
 
     :param partition_clause: a partial SQL statement that is added to a WHERE clause in the query built by
         the operator that creates partition_clauses for the checks to run on, e.g.
 
-    .. code-block:: python
+        .. code-block:: python
 
-        "date = '1970-01-01'"
+            "date = '1970-01-01'"
 
     :param conn_id: the connection ID used to connect to the database
     :param database: name of database which overwrite the defined one in connection
@@ -613,7 +625,7 @@ class SQLTableCheckOperator(BaseSQLOperator):
         self.log.info("All tests have passed")
 
     def _generate_sql_query(self):
-        self.log.info("Partition clause: %s", self.partition_clause)
+        self.log.debug("Partition clause: %s", self.partition_clause)
 
         def _generate_partition_clause(check_name):
             if self.partition_clause and "partition_clause" not in self.checks[check_name]:
@@ -807,12 +819,11 @@ class SQLIntervalCheckOperator(BaseSQLOperator):
     :param date_filter_column: The column name for the dates to filter on. Defaults to 'ds'
     :param ratio_formula: which formula to use to compute the ratio between
         the two metrics. Assuming cur is the metric of today and ref is
-        the metric to today - days_back.
+        the metric to today - days_back. Default: 'max_over_min'
 
-        max_over_min: computes max(cur, ref) / min(cur, ref)
-        relative_diff: computes abs(cur-ref) / ref
+        * ``max_over_min``: computes max(cur, ref) / min(cur, ref)
+        * ``relative_diff``: computes abs(cur-ref) / ref
 
-        Default: 'max_over_min'
     :param ignore_zero: whether we should ignore zero metrics
     :param metrics_thresholds: a dictionary of ratios indexed by metrics
     """
@@ -1029,7 +1040,7 @@ class BranchSQLOperator(BaseSQLOperator, SkipMixin):
 
     :param sql: The SQL code to be executed, should return true or false (templated)
        Template reference are recognized by str ending in '.sql'.
-       Expected SQL query to return Boolean (True/False), integer (0 = False, Otherwise = 1)
+       Expected SQL query to return a boolean (True/False), integer (0 = False, Otherwise = 1)
        or string (true/y/yes/1/on/false/n/no/0/off).
     :param follow_task_ids_if_true: task id or task ids to follow if query returns true
     :param follow_task_ids_if_false: task id or task ids to follow if query returns false
